/*
 * Copyright(c)  2002  Rijkswaterstaat
 *                     Adviesdienst Verkeer en Vervoer
 *                     WSRA
 * File:               CRAPTAB.C
 *
 * Regelprogramma vri: Voorbeeldregeling RichtingGevoelige Hiaatmeting
 *
 * datum:              31 augustus 1994
 * gewijzigd:          27 oktober 2003
 *
 * versie:             2.2
 */



#include "crtypes.h"
#include "crapcod.h"
#include "craptab.h"
#include "ccie_int.h"
#include "crapdef.h"


/*
 * =============================================================
 * declaraties t.b.v. het blokkenschema
 * =============================================================
 */

/*     BLOKKEN schema                                           */
struct BLOKKEN  BLOKKEN_tabel[] = {
/*     blok:    sg:     toewijzing:                             */
/*     BKl,     SGn,    PRIM + WSGR + ALT,                      */
       BK1,      SG02,  PRIM,
       BK2,      SG05,  PRIM,
       BK3,      SG28,  PRIM,
       STOP};

/*
 * =============================================================
 * matrices
 * =============================================================
 */

/*     CONFLICT- en (garantie)ontruimingstijden matrix          */
struct CONFLICT  CONFLICT_tabel[] = {
/*                                    instellingen              */
/*                                    van de tijden:            */
/*     sg:       conflicterende sg:   GO_TIJD:  O_TIJD:         */
/*     SGn,      SGj,                 x.y,      x.y,            */
       SG02,   SG05,                0.0,      0.0,
       SG02,   SG28,                2.0,      3.0,
       SG05,   SG02,                1.0,      4.0,
       SG05,   SG28,                3.0,      4.0,
       SG28,   SG02,                0.0,      0.0,
       SG28,   SG05,                0.0,      0.0,
       STOP};

/*
 * =============================================================
 * declaraties t.b.v. de signaalgroepprocedure
 * =============================================================
 */

/*     SignaalGroep_TIJDEN tabel                                */
struct SG_TIJDEN        SG_TIJDEN_tabel[] = {
/*            instellingen van de tijden:                       */
/*     sg:    GG_TIJD:  VG_TIJD:  GGL_TIJD:  GL_TIJD:  GR_TIJD: */
/*     SGn,    x.y,      x.y,      x.y,       x.y,      x.y,    */
       SG02,   4.0,      4.0,      4.0,       4.0,      2.0,
       SG05,   4.0,      4.0,      3.0,       3.0,      2.0,
       SG28,   4.0,      4.0,      3.0,       3.0,      2.0,
       STOP};

/*     MG_TIJDEN tabel                                          */
struct MG_TIJDEN        MG_TIJDEN_tabel[] = {
/*            instellingen (x.y of NG) van de tijden:           */
/*     sg:    MG_TIJD:  MG_TIJD1:  MG_TIJD2:  MG_TIJD3:         */
/*     SGn,    x.y,      x.y,       x.y,       x.y,             */
       SG02,    NG,     60.0,      60.0,      60.0,
       SG05,    NG,     60.0,      60.0,      60.0,
       SG28,    NG,     20.0,      20.0,      20.0,
       STOP};

/*     HiaatTIJDEN tabel                                        */
struct H_TIJDEN  H_TIJDEN_tabel[] = {
/*               instellingen (x.y of NG) van de tijden:        */
/*     sg:       H1e_TIJD:   H2e_TIJD:                          */
/*     SGn,       x.y,        x.y,                              */
       SG02,      1.0,        2.0,
       SG05,      1.0,         NG,
       SG28,      1.0,        2.0,
       STOP};

/*     SignaalGroep-DETECTIE tabel                              */
struct SG_DETECTIE           SG_DETECTIE_tabel[] = {
/*     D():       type:        sg:     toewijzing:               */
/*     SGn_i,     DP (of DK),  SGn,    AVR + BS_H5p + H1e + H2e, */
       SG02_1,          DP,   SG02,      BS_H5p,
       SG02_2,          DP,   SG02,      AVR,
       SG02_3,          DP,   SG02,      AVR,
       SG02_4,          DP,   SG02,      AVR,
       SG02_5,          DP,   SG02,      AVR,
       SG05_1,          DP,   SG05,      AVR,
       SG05_2,          DP,   SG05,      AVR,
       SG28_1,          DP,   SG28,      AVR + H1e,
       SG28_2,          DP,   SG28,      AVR,
       SG28_3,          DP,   SG28,      AVR,
       STOP};

/*
 * =============================================================
 * tijden, klokken en schakelaars
 * =============================================================
 */

/*     TIJDEN tabel                                             */
struct TIJDEN           TIJDEN_tabel[] = {
/*     TIJD():          instelling:                             */
/*     NAAM ,            x.y,                                   */
       T_DELAY,          0.3,
       STOP};

/*
 * ================================================================
 * tabel met gekoppelde regelingen
 * ================================================================
 */

/*     REGELING tabel                                              */
struct REGELING   REGELING_tabel[] = {
/*     Nummer,  */
            1,
       STOP};

struct WB                 WB_tabel[] = {STOP};
struct FICT_CONFLICT      FICT_CONFLICT_tabel[] = {STOP};
struct SG_BS_H5t          SG_BS_H5t_tabel[] = {STOP};
struct SG_BS_H5ac         SG_BS_H5ac_tabel[] = {STOP};
struct SG_BS_H66          SG_BS_H66_tabel[] = {STOP};
struct E_MG_TIJDEN        E_MG_TIJDEN_tabel[] = {STOP};
struct E_H_TIJDEN         E_H_TIJDEN_tabel[] = {STOP};
struct SG_RGA             SG_RGA_tabel[] = {STOP};
struct FIETS_VOETG_R      FIETS_VOETG_R_tabel[] = {STOP};
struct SG_MAH3            SG_MAH3_tabel[] = {STOP};
struct SG_PPAH            SG_PPAH_tabel[] = {STOP};
struct SG_WSRH            SG_WSRH_tabel[] = {STOP};
struct KLOKKEN            KLOKKEN_tabel[] = {STOP};
struct SCHAKELAAR         SCHAKELAAR_tabel[] = {STOP};
struct EPARMS             EPARMS_tabel[] = {STOP};
struct EGGPARMS           EGGPARMS_tabel[] = {STOP};
struct BK_OPTIE           BO_OP_tabel[] = {STOP};
struct SG_OPTIE           MA_OP_tabel[] = {STOP};
struct SG_BK_OPTIE        PPP_OP_tabel[] = {STOP};
struct SG_OPTIE           MVG_OP_tabel[] = {STOP};
struct SG_OPTIE           TR_OP_tabel[] = {STOP};
struct SG_OPTIE           VAA_OP_tabel[] = {STOP};
struct SG_OPTIE           PPV_OP_tabel[] = {STOP};
struct SG_OPTIE           PPB_OP_tabel[] = {STOP};
struct SG_BK_OPTIE        PPA_OP_tabel[] = {STOP};
struct SG_BK_OPTIE        VNM_OP_tabel[] = {STOP};
struct SG_OPTIE           AFK_OP_tabel[] = {STOP};
struct SG_OPTIE           BL_OP_tabel[] = {STOP};
struct SG_OPTIE           RVG_OP_tabel[] = {STOP};
struct SG_OPTIE           VAG_OP_tabel[] = {STOP};
struct SG_OPTIE           VMG_OP_tabel[] = {STOP};
struct KOPPEL             KOPPEL_tabel[] = {STOP};



